==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSortingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebSortingExpressionEventArgsDescription } from "./WebSortingExpressionEventArgsDescription";
/**
 * @hidden
 */
var WebSortingExpressionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingExpressionEventArgsDescriptionMetadata, _super);
    function WebSortingExpressionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingExpressionEventArgsDescriptionMetadata.b = function (a) {
        if (WebSortingExpressionEventArgsDescriptionMetadata.a == null) {
            WebSortingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingExpressionEventArgsDescriptionMetadata.c(WebSortingExpressionEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebSortingExpressionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSortingExpressionEventArgsDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
    };
    WebSortingExpressionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingExpressionEventArgs");
        a.item("Detail", "Array:WebSortingExpressionDescription:SortingExpression");
    };
    WebSortingExpressionEventArgsDescriptionMetadata.d = function (a) {
        WebSortingExpressionEventArgsDescriptionMetadata.b(a);
        a.aa("WebSortingExpressionEventArgs", function () { return new WebSortingExpressionEventArgsDescription(); });
        a.z("WebSortingExpressionEventArgs", WebSortingExpressionEventArgsDescriptionMetadata.a);
    };
    WebSortingExpressionEventArgsDescriptionMetadata.$t = markType(WebSortingExpressionEventArgsDescriptionMetadata, 'WebSortingExpressionEventArgsDescriptionMetadata');
    WebSortingExpressionEventArgsDescriptionMetadata.a = null;
    return WebSortingExpressionEventArgsDescriptionMetadata;
}(Base));
export { WebSortingExpressionEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebSortingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebSortingExpressionEventArgsDescription } from "./WebSortingExpressionEventArgsDescription";
/**
 * @hidden
 */
var WebSortingExpressionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingExpressionEventArgsDescriptionMetadata, _super);
    function WebSortingExpressionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingExpressionEventArgsDescriptionMetadata.b = function (a) {
        if (WebSortingExpressionEventArgsDescriptionMetadata.a == null) {
            WebSortingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingExpressionEventArgsDescriptionMetadata.c(WebSortingExpressionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebSortingExpressionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSortingExpressionEventArgsDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
    };
    WebSortingExpressionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingExpressionEventArgs");
        a.item("Detail", "Array:WebSortingExpressionDescription:SortingExpression");
    };
    WebSortingExpressionEventArgsDescriptionMetadata.d = function (a) {
        WebSortingExpressionEventArgsDescriptionMetadata.b(a);
        a.ac("WebSortingExpressionEventArgs", function () { return new WebSortingExpressionEventArgsDescription(); });
        a.ab("WebSortingExpressionEventArgs", WebSortingExpressionEventArgsDescriptionMetadata.a);
    };
    WebSortingExpressionEventArgsDescriptionMetadata.$t = markType(WebSortingExpressionEventArgsDescriptionMetadata, 'WebSortingExpressionEventArgsDescriptionMetadata');
    WebSortingExpressionEventArgsDescriptionMetadata.a = null;
    return WebSortingExpressionEventArgsDescriptionMetadata;
}(Base));
export { WebSortingExpressionEventArgsDescriptionMetadata };
